@@ -1,4 +1,4 @@
-from signal import signal, SIGINT, SIGTERM
+from signal import SIGINT, SIGTERM, signal
 
 
 class Terminated:
